@@ -41,6 +41,9 @@ class PrincipalWidget(TextWidget):
 
     implementsOnly(IPrincipalWidget)
 
+    query_name = 'findPrincipals'
+    auth_plugins = ()
+
     @property
     def principal(self):
         return getPrincipal(self.value)
@@ -55,6 +58,10 @@ class PrincipalWidget(TextWidget):
         return "{ '%s': '%s' }" % (principal.id,
                                    principal.title.replace("'", "&#039;"))
 
+    @property
+    def auth_plugins_value(self):
+        return (";;{'names':'%s'}" % ','.join(self.auth_plugins)) if self.auth_plugins else ''
+
     def render(self):
         jquery_multiselect.need()
         return super(PrincipalWidget, self).render()
@@ -72,16 +79,23 @@ class PrincipalListWidget(TextWidget):
 
     implementsOnly(IPrincipalListWidget)
 
+    query_name = 'findPrincipals'
+    auth_plugins = ()
+
     @property
     def principals(self):
         if not hasattr(self, '_v_principals'):
-            self._v_principals = sorted([getPrincipal(v) for v in self.value.split(',')], key=lambda x: x.title)
+            self._v_principals = sorted((getPrincipal(v) for v in self.value.split(',')), key=lambda x: x.title)
         return self._v_principals
 
     @property
     def principals_map(self):
-        return '{ %s }' % ',\n'.join(["'%s': '%s'" % (principal.id, principal.title.replace("'", "&#039;"))
-                                      for principal in self.principals])
+        return '{ %s }' % ',\n'.join(("'%s': '%s'" % (principal.id, principal.title.replace("'", "&#039;"))
+                                      for principal in self.principals))
+
+    @property
+    def auth_plugins_value(self):
+        return (";;{'names':'%s'}" % ','.join(self.auth_plugins)) if self.auth_plugins else ''
 
     def render(self):
         jquery_multiselect.need()
